Crate rig_mongodb

Crate rig_mongodb 

MongoDB vector store integration for Rig.

This crate provides MongoDbVectorIndex, a Rig vector store index backed by MongoDB Atlas Vector Search or compatible MongoDB vector search indexes.

The root rig facade re-exports this crate as rig::mongodb when the mongodb feature is enabled.

Structs

MongoDbSearchFilter
MongoDbVectorIndex
A vector index for a MongoDB collection.
SearchParams
See MongoDB Vector Search for more information on each of the fields